<?php

	/* 
	
	|------------------------------------------------------------------------------
	|  NAME: tsampaPRtable, version 0.1 (31 May 2005)
	|  URL: http://tsampa.org/training/software/tsampaprtable/
	|  AUTHOR: (c) Kristoffer Lindqvist, 2005 <kris@tsampa.org>
	|  LICENSE: http://www.gnu.org/licenses/gpl.txt
	|  	This program is free software; you can redistribute it and/or modify
	|    	it under the terms of the GNU General Public License as published by
	|       the Free Software Foundation; either version 2 of the License, or
	|    	(at your option) any later version.
	|
	| 	This program is distributed in the hope that it will be useful,
	|	but WITHOUT ANY WARRANTY; without even the implied warranty of
	|       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	|	GNU General Public License for more details.
	|  DESCRIPTION:
	|	tsampaPRtable is a PHP script to render a personal record
	|	matrix out of a plain textfile. It was written after I got
	|	bloody tired of having to find and replace rows in my
	|	html pr matrix every month. Read the attached README.txt file 
	|	or browse over to the project home page for further instructions.
	|_______________________________________________________________________________

	*/

	function tsampaPRtable($filename, $startyear, $startmonth, $endyear="0", $endmonth="0") {

		// ********** VARIABLES YOU MIGHT WANT TO TWEAK *****************

		// name of every month 
		$months = array(1 => 'Jan','Feb','Mar','Apr','May','Jun','Jul', 'Aug','Sep', 'Oct','Nov','Dec');
		
		// insert timeline every X lines, default '5'
		$timelineSpacing = '5'; 

		// how wide to force the exercise name column in pixels, default '120'
		$firstcolumnwidth = '120';

		// how wide to force other columns in pixels, default '100'
		$columnwidth = '100';  // how wide to force columns in pixels
		
		// name of transparent image used to force columns out
		$spacerimg = 'filler.png';

		// write out the exercise name at end of table as well (true/false), default true
		$namesLast = true;

		// what to write in the remarks column, default 'Remarks'
		$remarksStr = 'Remarks';

		// what to write in the PR column, default 'PR'
		$prStr = 'PR';

		// how to delimit PRs that fall on the same month, default '<br />' (linebreak)
		$prDelimit = '<br />';

		// show PR column (true/false), default true
		$showPRcolumn = true;

		// ***************************************************************
	
		if ($endyear != "0") {
			$thisyear=$endyear;
			$thismonth=str_pad($endmonth,2,'0',STR_PAD_LEFT);
		} else {
			$thisyear = date('Y');
			$thismonth = date('m');
		}
		$fillerstr = '<img src="'.$spacerimg.'" height="1" width="'.$columnwidth.'" alt="" />';
		$fillerstrFirst = '<img src="'.$spacerimg.'" height="1" width="'.$firstcolumnwidth.'" alt="" />';

		// make sure the dates make sense
		if (!ctype_digit($startyear.$startmonth)) {
			echo 'tsampaPRtable: invalid date values passed '.$startyear.$startmonth;
			exit;
		} elseif ($startyear.$startmonth > $thisyear.$thismonth) {
			if ($endyear=="0") {
				echo 'tsampaPRtable: Start dates '.$startyear.$startmonth.' are in the future ';
				echo 'or the server returns invalid date for today ('.$thisyear.$thismonth.')';
			} else {
				echo 'tsampaPRtable: Start date '.$startyear.$startmonth.' is later than ';
				echo 'end date '.$thisyear.$thismonth.'!';
			}
			exit;
		}

                // open the requested file if found
		if (file_exists($filename)) {
			$lines=file($filename);
			if (!file_exists($spacerimg)) {
				echo 'progressTable error: Spacer img not found '.$spacerimg;
				exit;
			}
		} else { 
			echo 'progressTable error: File not found '.$filename;
			exit;
		} 
		echo '<table class="prtable">';
		$i=-1;
		$tmlcounter = 0;

		while ($i < sizeof($lines)-1) {
			$dotimeline = false;
			$doexercise = false;
			$isremarks = false;
			if ($tmlcounter <= 0) {
				$dotimeline=true;
				$tmlcounter=$timelineSpacing;
			} elseif ($lines[$i][0] == '*') {
				$doexercise=true;
				$tmlcounter -= 1;
				if (($i == "0") and (strtolower(trim($lines[$i])) == '*remarks')) {
					$isremarks=true;
				}
			}
	
			if (($dotimeline) or ($doexercise)) {
				if ($doexercise) {
					$pr = "-1";
					if (!$isremarks) {
						$exname = substr($lines[$i],1);
						$tdclass = 'class="pr"';
						echo '<tr><td class="exercisename">';
					} else {
						$exname = $remarksStr;
						$tdclass = 'class="remarks" ';
						echo '<tr><td class="remarksside">';
					}
					echo $exname.'</td>';
					// check for PR
					if ($endyear != "0") {
						// we don't want to list whole table -> look for
						// PRs which match the last date
						$ii = $i+1;
						while (($ii < sizeof($lines)-1) and (ctype_digit(substr($lines[$ii],0,6)))) {
							if ((substr($lines[$ii],0,6)) <= $thisyear.$thismonth) {
								$pr = substr($lines[$ii],8);
								$i = $ii-1;
								break;
							}
							$ii += 1;
						}
					} else {
						// per definition, the first entry following the
						// exercise name should be the PR if we want to
						// list the whole table. No checks are done to
						// see if this is correct
						if ($i < sizeof($lines)) $pr = substr($lines[$i+1],8);
					}
					if ($showPRcolumn) {
						echo '<td '.$tdclass.'>';
						if (($pr != "-1") and (!$isremarks)) echo $pr;
						echo '</td>';
					}
				} else { 
					echo '<tr><td class="timeline" width="'.$firstcolumnwidth.'">'.$fillerstrFirst;
					if ($showPRcolumn) echo '</td><td class="timeline" width="'.$columnwidth.'">'.$prStr.'<br />'.$fillerstr.'</td>';
				}
				$tmpyear=$thisyear;
				$tmpmonth=$thismonth;
				$tdclass='';
			 	if (!$dotimeline) $i += 1;

				// main loop to render complete row for one exercise or timeline
				while ($tmpyear.$tmpmonth>=$startyear.$startmonth) {

					if ($doexercise) {
						// check if current entry is a date entry for
						// the exercise. If not, change class to 
						// 'inactive'
						if ($isremarks) {
							$tdclass='class="remarks"';
						} elseif (($pr == "-1") or (($i <= sizeof($lines)) and (!ctype_digit(substr($lines[$i],0,6))))) {
							$tdclass='class="inactive"';
						}
	
						echo '<td '.$tdclass.'>'; 
	
						$tmpbreak = '';
						while (($i <= sizeof($lines)) and (substr($lines[$i],0,6)==$tmpyear.$tmpmonth)) {
							echo $tmpbreak.substr($lines[$i],8);
							$i+=1;
							$tmpbreak = $prDelimit;

						}
					} else {
						echo '<td class="timeline">';
						if (($tmpmonth=='12') or ($tmpyear.$tmpmonth==$thisyear.$thismonth)) echo '<strong class="yearchange">'.$tmpyear.'</strong> ';
						echo ($months[ltrim($tmpmonth, '0')]);
						echo '<br />'.$fillerstr;
					}
					echo '</td>';
		
					$tmpmonth = str_pad($tmpmonth-1,2,'0',STR_PAD_LEFT);
					if ($tmpmonth < 1) {
						$tmpyear -= 1;
						$tmpmonth = '12';
					}
				}
				if ($namesLast) {
					if ($doexercise) {
						if ($isremarks) {
							echo '<td class="remarks">';
						} else {
							echo '<td class="exercisename">';
						}
						echo $exname.'</td>';
					} else {
						echo '<td class="timeline">'.$fillerstrFirst.'</td>';
					}
				}
				echo '</tr>';
			}
			if (!$dotimeline) $i += 1;
		}

		echo '</table>';

	}

// ************************* HTML SECTION ***********************************

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title>tsampaPRtable test page</title>
	<style type="text/css" media="screen">
		table.prtable {
			background-color: #999;
			font-family: Arial;
			font-size: 12px;
			margin: 2px 20px 2px 2px;
		}

		.prtable td {
			background-color: white;
		}

		.prtable td.exercisename {
			font-size: 14px;
		}

		.prtable td.remarksside {
			background-color: #ccffcc;
			font-size: 14px;
		}

		.prtable td.remarks {
			background-color: #ccffcc;
		}

		.prtable td.inactive {
			background-color: #ccc;
		}

		.prtable td.timeline {
			background-color: #ff9999;
			text-align: center;
		}

		.prtable td.pr {
			background-color: #ffff99;
		}

		.prtable strong.yearchange {
			background-color: white;
		}

		p.poweredbyPRtable {
			font-family: Arial, sans-serif;
			font-size: 12px;
			font-style: italic;
		}
	</style>
</head>
<body>

	<h1>My Personal Records</h1>

	<?php 
	
		tsampaPRtable("pr.inc", "2003", "05", "2003", "12"); 

		// I'd appreciate it if you would leave this notice intact or 
		// at least display it somewhere on the page
		print '<p class="poweredbyPRtable">Powered by <a href="http://tsampa.org/training/software/tsampaprtable/">tsampaPRtable</a>, v0.1</p>'; 
	?>

</body>
</html>
